@@ -44,7 +44,7 @@ typedef struct _CoglPangoDisplayListRectangle CoglPangoDisplayListRectangle;
 
 struct _CoglPangoDisplayList
 {
-  gboolean                color_override;
+  CoglBool                color_override;
   CoglColor               color;
   GSList                 *nodes;
   GSList                 *last_node;
@@ -62,7 +62,7 @@ struct _CoglPangoDisplayListNode
 {
   CoglPangoDisplayListNodeType type;
 
-  gboolean color_override;
+  CoglBool color_override;
   CoglColor color;
 
   CoglPipeline *pipeline;
@@ -261,7 +261,7 @@ emit_vertex_buffer_geometry (CoglPangoDisplayListNode *node)
       CoglAttributeBuffer *buffer;
       CoglVertexP2T2 *verts, *v;
       int n_verts;
-      gboolean allocated = FALSE;
+      CoglBool allocated = FALSE;
       CoglAttribute *attributes[2];
       CoglPrimitive *prim;
       int i;
@@ -437,9 +437,12 @@ _cogl_pango_display_list_render (CoglPangoDisplayList *dl,
 
         case COGL_PANGO_DISPLAY_LIST_TRAPEZOID:
           {
+            CoglFramebuffer *framebuffer = cogl_get_draw_framebuffer ();
             float points[8];
             CoglPath *path;
 
+            _COGL_GET_CONTEXT (ctx, NO_RETVAL);
+
             points[0] =  node->d.trapezoid.x_11;
             points[1] =  node->d.trapezoid.y_1;
             points[2] =  node->d.trapezoid.x_12;
@@ -451,7 +454,7 @@ _cogl_pango_display_list_render (CoglPangoDisplayList *dl,
 
             path = cogl_path_new ();
             cogl_path_polygon (path, points, 4);
-            cogl_path_fill (path);
+            cogl_framebuffer_fill_path (framebuffer, node->pipeline, path);
             cogl_object_unref (path);
           }
           break;
