@@ -30,8 +30,8 @@ G_BEGIN_DECLS
 
 void           _cogl_pango_renderer_clear_glyph_cache  (CoglPangoRenderer *renderer);
 void           _cogl_pango_renderer_set_use_mipmapping (CoglPangoRenderer *renderer,
-                                                        gboolean           value);
-gboolean       _cogl_pango_renderer_get_use_mipmapping (CoglPangoRenderer *renderer);
+                                                        CoglBool           value);
+CoglBool       _cogl_pango_renderer_get_use_mipmapping (CoglPangoRenderer *renderer);
 
 G_END_DECLS
 
