@@ -28,10 +28,41 @@
 
 #include <glib.h>
 
-#include "cogl-handle.h"
+#include "cogl-object-private.h"
 #include "cogl-buffer.h"
 #include "cogl-bitmap.h"
 
+#ifdef COGL_HAS_ANDROID_SUPPORT
+#include <android/asset_manager.h>
+#endif
+
+struct _CoglBitmap
+{
+  CoglObject _parent;
+
+  /* Pointer back to the context that this bitmap was created with */
+  CoglContext *context;
+
+  CoglPixelFormat format;
+  int width;
+  int height;
+  int rowstride;
+
+  uint8_t *data;
+
+  CoglBool mapped;
+  CoglBool bound;
+
+  /* If this is non-null then 'data' is ignored and instead it is
+     fetched from this shared bitmap. */
+  CoglBitmap *shared_bmp;
+
+  /* If this is non-null then 'data' is treated as an offset into the
+     buffer and map will divert to mapping the buffer */
+  CoglBuffer *buffer;
+};
+
+
 /*
  * _cogl_bitmap_new_with_malloc_buffer:
  * @context: A #CoglContext
@@ -71,25 +102,34 @@ CoglBitmap *
 _cogl_bitmap_convert (CoglBitmap *bmp,
 		      CoglPixelFormat   dst_format);
 
-gboolean
+CoglBool
 _cogl_bitmap_convert_into_bitmap (CoglBitmap *src_bmp,
                                   CoglBitmap *dst_bmp);
 
 CoglBitmap *
-_cogl_bitmap_from_file (const char *filename,
-			GError     **error);
+_cogl_bitmap_from_file (CoglContext *ctx,
+                        const char *filename,
+			GError **error);
 
-gboolean
+#ifdef COGL_HAS_ANDROID_SUPPORT
+CoglBitmap *
+_cogl_android_bitmap_new_from_asset (CoglContext *ctx,
+                                     AAssetManager *manager,
+                                     const char *filename,
+                                     GError **error);
+#endif
+
+CoglBool
 _cogl_bitmap_unpremult (CoglBitmap *dst_bmp);
 
-gboolean
+CoglBool
 _cogl_bitmap_premult (CoglBitmap *dst_bmp);
 
-gboolean
+CoglBool
 _cogl_bitmap_convert_premult_status (CoglBitmap      *bmp,
                                      CoglPixelFormat  dst_format);
 
-gboolean
+CoglBool
 _cogl_bitmap_copy_subregion (CoglBitmap *src,
 			     CoglBitmap *dst,
 			     int         src_x,
@@ -103,7 +143,7 @@ _cogl_bitmap_copy_subregion (CoglBitmap *src,
 CoglBitmap *
 _cogl_bitmap_copy (CoglBitmap *src_bmp);
 
-gboolean
+CoglBool
 _cogl_bitmap_get_size_from_file (const char *filename,
                                  int        *width,
                                  int        *height);
@@ -120,7 +160,7 @@ _cogl_bitmap_set_format (CoglBitmap *bitmap,
    uploads data using gdk_pixbuf_new_subpixbuf with a sub region
    containing the last row of the pixbuf because in that case the
    rowstride can be much larger than the width of the image */
-guint8 *
+uint8_t *
 _cogl_bitmap_map (CoglBitmap *bitmap,
                   CoglBufferAccess access,
                   CoglBufferMapHint hints);
@@ -134,7 +174,7 @@ _cogl_bitmap_unmap (CoglBitmap *bitmap);
    was created with new_from_buffer but it will however be good to
    pass to glTexImage2D for example. The access should be READ for
    unpacking and WRITE for packing. It can not be both */
-guint8 *
+uint8_t *
 _cogl_bitmap_bind (CoglBitmap *bitmap,
                    CoglBufferAccess access,
                    CoglBufferMapHint hints);
@@ -142,4 +182,7 @@ _cogl_bitmap_bind (CoglBitmap *bitmap,
 void
 _cogl_bitmap_unbind (CoglBitmap *bitmap);
 
+CoglContext *
+_cogl_bitmap_get_context (CoglBitmap *bitmap);
+
 #endif /* __COGL_BITMAP_H */
