@@ -25,7 +25,7 @@
  *   Robert Bragg <robert@linux.intel.com>
  */
 
-#if !defined(__COGL_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
+#if !defined(__COGL_H_INSIDE__) && !defined(COGL_COMPILATION)
 #error "Only <cogl/cogl.h> can be included directly."
 #endif
 
@@ -74,7 +74,7 @@ typedef struct _CoglBuffer CoglBuffer;
  * Since: 1.2
  * Stability: unstable
  */
-gboolean
+CoglBool
 cogl_is_buffer (void *object);
 
 /**
@@ -231,11 +231,11 @@ cogl_buffer_unmap (CoglBuffer *buffer);
  * Since: 1.2
  * Stability: unstable
  */
-gboolean
-cogl_buffer_set_data (CoglBuffer  *buffer,
-                      gsize        offset,
-                      const void  *data,
-                      gsize        size);
+CoglBool
+cogl_buffer_set_data (CoglBuffer *buffer,
+                      size_t offset,
+                      const void *data,
+                      size_t size);
 
 G_END_DECLS
 
