@@ -150,8 +150,8 @@ cogl_euler_init_from_matrix (CoglEuler *euler,
   euler->roll = R;
 }
 
-gboolean
-cogl_euler_equal (gconstpointer v1, gconstpointer v2)
+CoglBool
+cogl_euler_equal (const void *v1, const void *v2)
 {
   const CoglEuler *a = v1;
   const CoglEuler *b = v2;
