@@ -1597,7 +1597,7 @@ cogl_gles2_context_new (CoglContext *ctx, GError **error)
                        extension_suffixes, extension_names)
 
 #define COGL_EXT_FUNCTION(ret, name, args) \
-  gles2_ctx->vtable->name = ctx->name;
+  gles2_ctx->vtable->name = (void *) ctx->name;
 
 #define COGL_EXT_END()
 
@@ -1607,10 +1607,15 @@ cogl_gles2_context_new (CoglContext *ctx, GError **error)
 #undef COGL_EXT_FUNCTION
 #undef COGL_EXT_END
 
-  gles2_ctx->vtable->glBindFramebuffer = gl_bind_framebuffer_wrapper;
-  gles2_ctx->vtable->glReadPixels = gl_read_pixels_wrapper;
-  gles2_ctx->vtable->glCopyTexImage2D = gl_copy_tex_image_2d_wrapper;
-  gles2_ctx->vtable->glCopyTexSubImage2D = gl_copy_tex_sub_image_2d_wrapper;
+  gles2_ctx->vtable->glBindFramebuffer =
+    (void *) gl_bind_framebuffer_wrapper;
+  gles2_ctx->vtable->glReadPixels =
+    (void *) gl_read_pixels_wrapper;
+  gles2_ctx->vtable->glCopyTexImage2D =
+    (void *) gl_copy_tex_image_2d_wrapper;
+  gles2_ctx->vtable->glCopyTexSubImage2D =
+    (void *) gl_copy_tex_sub_image_2d_wrapper;
+
   gles2_ctx->vtable->glCreateShader = gl_create_shader_wrapper;
   gles2_ctx->vtable->glDeleteShader = gl_delete_shader_wrapper;
   gles2_ctx->vtable->glCreateProgram = gl_create_program_wrapper;
@@ -1639,10 +1644,6 @@ cogl_gles2_context_new (CoglContext *ctx, GError **error)
   gles2_ctx->vtable->glBindTexture = gl_bind_texture_wrapper;
   gles2_ctx->vtable->glTexImage2D = gl_tex_image_2d_wrapper;
 
-  /* FIXME: we need to do something with glCopyTexImage2D and
-   * glCopySubTexImage2D so that it will flip the data if it is read
-   * from a CoglOffscreen */
-
   gles2_ctx->shader_map =
     g_hash_table_new_full (g_direct_hash,
                            g_direct_equal,
