@@ -25,7 +25,7 @@
 #define __COGL_JOURNAL_PRIVATE_H
 
 #include "cogl-texture.h"
-#include "cogl-handle.h"
+#include "cogl-object-private.h"
 #include "cogl-clip-stack.h"
 
 #define COGL_JOURNAL_VBO_POOL_SIZE 8
@@ -67,13 +67,10 @@ typedef struct _CoglJournalEntry
 {
   CoglPipeline            *pipeline;
   int                      n_layers;
-  CoglMatrix               model_view;
+  CoglMatrixEntry         *modelview_entry;
   CoglClipStack           *clip_stack;
   /* Offset into ctx->logged_vertices */
   size_t                   array_offset;
-  /* XXX: These entries are pretty big now considering the padding in
-   * CoglPipelineFlushOptions and CoglMatrix, so we might need to optimize this
-   * later. */
 } CoglJournalEntry;
 
 CoglJournal *
@@ -94,21 +91,21 @@ _cogl_journal_flush (CoglJournal *journal);
 void
 _cogl_journal_discard (CoglJournal *journal);
 
-gboolean
+CoglBool
 _cogl_journal_all_entries_within_bounds (CoglJournal *journal,
                                          float clip_x0,
                                          float clip_y0,
                                          float clip_x1,
                                          float clip_y1);
 
-gboolean
+CoglBool
 _cogl_journal_try_read_pixel (CoglJournal *journal,
                               int x,
                               int y,
                               CoglBitmap *bitmap,
-                              gboolean *found_intersection);
+                              CoglBool *found_intersection);
 
-gboolean
+CoglBool
 _cogl_is_journal (void *object);
 
 #endif /* __COGL_JOURNAL_PRIVATE_H */
