@@ -360,11 +360,38 @@ _cogl_matrix_multiply_array (CoglMatrix *result, const float *array)
  * Called by _cogl_matrix_print() to print a matrix or its inverse.
  */
 static void
-print_matrix_floats (const float m[16])
+print_matrix_floats (const char *prefix, const float m[16])
 {
   int i;
   for (i = 0;i < 4; i++)
-    g_print ("\t%f %f %f %f\n", m[i], m[4+i], m[8+i], m[12+i] );
+    g_print ("%s\t%f %f %f %f\n", prefix, m[i], m[4+i], m[8+i], m[12+i] );
+}
+
+void
+_cogl_matrix_prefix_print (const char *prefix, const CoglMatrix *matrix)
+{
+  if (!(matrix->flags & MAT_DIRTY_TYPE))
+    {
+      _COGL_RETURN_IF_FAIL (matrix->type < COGL_MATRIX_N_TYPES);
+      g_print ("%sMatrix type: %s, flags: %x\n",
+               prefix, types[matrix->type], (int)matrix->flags);
+    }
+  else
+    g_print ("%sMatrix type: DIRTY, flags: %x\n",
+             prefix, (int)matrix->flags);
+
+  print_matrix_floats (prefix, (float *)matrix);
+  g_print ("%sInverse: \n", prefix);
+  if (!(matrix->flags & MAT_DIRTY_INVERSE))
+    {
+      float prod[16];
+      print_matrix_floats (prefix, matrix->inv);
+      matrix_multiply4x4 (prod, (float *)matrix, matrix->inv);
+      g_print ("%sMat * Inverse:\n", prefix);
+      print_matrix_floats (prefix, prod);
+    }
+  else
+    g_print ("%s  - not available\n", prefix);
 }
 
 /*
@@ -373,27 +400,7 @@ print_matrix_floats (const float m[16])
 void
 _cogl_matrix_print (const CoglMatrix *matrix)
 {
-  if (!(matrix->flags & MAT_DIRTY_TYPE))
-    {
-      _COGL_RETURN_IF_FAIL (matrix->type < COGL_MATRIX_N_TYPES);
-      g_print ("Matrix type: %s, flags: %x\n",
-               types[matrix->type], (int)matrix->flags);
-    }
-  else
-    g_print ("Matrix type: DIRTY, flags: %x\n", (int)matrix->flags);
-
-  print_matrix_floats ((float *)matrix);
-  g_print ("Inverse: \n");
-  if (!(matrix->flags & MAT_DIRTY_INVERSE))
-    {
-      float prod[16];
-      print_matrix_floats (matrix->inv);
-      matrix_multiply4x4 (prod, (float *)matrix, matrix->inv);
-      g_print ("Mat * Inverse:\n");
-      print_matrix_floats (prod);
-    }
-  else
-    g_print ("  - not available\n");
+  _cogl_matrix_prefix_print ("", matrix);
 }
 
 /*
@@ -431,7 +438,7 @@ _cogl_matrix_print (const CoglMatrix *matrix)
  * with partial pivoting followed by back/substitution with the loops manually
  * unrolled.
  */
-static gboolean
+static CoglBool
 invert_matrix_general (CoglMatrix *matrix)
 {
   const float *m = (float *)matrix;
@@ -570,7 +577,7 @@ invert_matrix_general (CoglMatrix *matrix)
  * element. Finally deals with the translation part by transforming the
  * original translation vector using by the calculated submatrix inverse.
  */
-static gboolean
+static CoglBool
 invert_matrix_3d_general (CoglMatrix *matrix)
 {
   const float *in = (float *)matrix;
@@ -652,12 +659,14 @@ invert_matrix_3d_general (CoglMatrix *matrix)
  * the inverse matrix analyzing and inverting each of the scaling, rotation and
  * translation parts.
  */
-static gboolean
+static CoglBool
 invert_matrix_3d (CoglMatrix *matrix)
 {
   const float *in = (float *)matrix;
   float *out = matrix->inv;
 
+  memcpy (out, identity, 16 * sizeof (float));
+
   if (!TEST_MAT_FLAGS(matrix, MAT_FLAGS_ANGLE_PRESERVING))
     return invert_matrix_3d_general (matrix);
 
@@ -735,7 +744,7 @@ invert_matrix_3d (CoglMatrix *matrix)
  *
  * Simply copies identity into CoglMatrix::inv.
  */
-static gboolean
+static CoglBool
 invert_matrix_identity (CoglMatrix *matrix)
 {
   memcpy (matrix->inv, identity, 16 * sizeof (float));
@@ -752,7 +761,7 @@ invert_matrix_identity (CoglMatrix *matrix)
  *
  * Calculates the
  */
-static gboolean
+static CoglBool
 invert_matrix_3d_no_rotation (CoglMatrix *matrix)
 {
   const float *in = (float *)matrix;
@@ -787,7 +796,7 @@ invert_matrix_3d_no_rotation (CoglMatrix *matrix)
  * Calculates the inverse matrix by applying the inverse scaling and
  * translation to the identity matrix.
  */
-static gboolean
+static CoglBool
 invert_matrix_2d_no_rotation (CoglMatrix *matrix)
 {
   const float *in = (float *)matrix;
@@ -811,7 +820,7 @@ invert_matrix_2d_no_rotation (CoglMatrix *matrix)
 
 #if 0
 /* broken */
-static gboolean
+static CoglBool
 invert_matrix_perspective (CoglMatrix *matrix)
 {
   const float *in = matrix;
@@ -841,7 +850,7 @@ invert_matrix_perspective (CoglMatrix *matrix)
 /*
  * Matrix inversion function pointer type.
  */
-typedef gboolean (*inv_mat_func)(CoglMatrix *matrix);
+typedef CoglBool (*inv_mat_func)(CoglMatrix *matrix);
 
 /*
  * Table of the matrix inversion functions according to the matrix type.
@@ -1099,7 +1108,7 @@ _cogl_matrix_update_type_and_flags (CoglMatrix *matrix)
  * given matrix type.  In case of failure, updates the MAT_FLAG_SINGULAR flag,
  * and copies the identity matrix into CoglMatrix::inv.
  */
-static gboolean
+static CoglBool
 _cogl_matrix_update_inverse (CoglMatrix *matrix)
 {
   if (matrix->flags & MAT_DIRTY_FLAGS ||
@@ -1124,7 +1133,7 @@ _cogl_matrix_update_inverse (CoglMatrix *matrix)
     return TRUE;
 }
 
-gboolean
+CoglBool
 cogl_matrix_get_inverse (const CoglMatrix *matrix, CoglMatrix *inverse)
 {
   if (_cogl_matrix_update_inverse ((CoglMatrix *)matrix))
@@ -1156,7 +1165,7 @@ _cogl_matrix_rotate (CoglMatrix *matrix,
 {
   float xx, yy, zz, xy, yz, zx, xs, ys, zs, one_c, s, c;
   float m[16];
-  gboolean optimized;
+  CoglBool optimized;
 
   s = sinf (angle * DEG2RAD);
   c = cosf (angle * DEG2RAD);
@@ -1345,6 +1354,26 @@ cogl_matrix_rotate (CoglMatrix *matrix,
   _COGL_MATRIX_DEBUG_PRINT (matrix);
 }
 
+void
+cogl_matrix_rotate_quaternion (CoglMatrix *matrix,
+                               const CoglQuaternion *quaternion)
+{
+  CoglMatrix rotation_transform;
+
+  cogl_matrix_init_from_quaternion (&rotation_transform, quaternion);
+  cogl_matrix_multiply (matrix, matrix, &rotation_transform);
+}
+
+void
+cogl_matrix_rotate_euler (CoglMatrix *matrix,
+                          const CoglEuler *euler)
+{
+  CoglMatrix rotation_transform;
+
+  cogl_matrix_init_from_euler (&rotation_transform, euler);
+  cogl_matrix_multiply (matrix, matrix, &rotation_transform);
+}
+
 /*
  * Apply a perspective projection matrix.
  *
@@ -1596,11 +1625,45 @@ cogl_matrix_init_identity (CoglMatrix *matrix)
   _COGL_MATRIX_DEBUG_PRINT (matrix);
 }
 
+/*
+ * Set a matrix to the (tx, ty, tz) translation matrix.
+ *
+ * @matix matrix.
+ * @tx x coordinate of the translation vector
+ * @ty y coordinate of the translation vector
+ * @tz z coordinate of the translation vector
+ */
+static void
+_cogl_matrix_init_translation (CoglMatrix *matrix,
+                               float       tx,
+                               float       ty,
+                               float       tz)
+{
+  memcpy (matrix, identity, 16 * sizeof (float));
+
+  matrix->xw = tx;
+  matrix->yw = ty;
+  matrix->zw = tz;
+
+  matrix->type = COGL_MATRIX_TYPE_3D;
+  matrix->flags = MAT_FLAG_TRANSLATION | MAT_DIRTY_INVERSE;
+}
+
+void
+cogl_matrix_init_translation (CoglMatrix *matrix,
+                              float       tx,
+                              float       ty,
+                              float       tz)
+{
+  _cogl_matrix_init_translation (matrix, tx, ty, tz);
+  _COGL_MATRIX_DEBUG_PRINT (matrix);
+}
+
 #if 0
 /*
  * Test if the given matrix preserves vector lengths.
  */
-static gboolean
+static CoglBool
 _cogl_matrix_is_length_preserving (const CoglMatrix *m)
 {
   return TEST_MAT_FLAGS (m, MAT_FLAGS_LENGTH_PRESERVING);
@@ -1610,7 +1673,7 @@ _cogl_matrix_is_length_preserving (const CoglMatrix *m)
  * Test if the given matrix does any rotation.
  * (or perhaps if the upper-left 3x3 is non-identity)
  */
-static gboolean
+static CoglBool
 _cogl_matrix_has_rotation (const CoglMatrix *matrix)
 {
   if (matrix->flags & (MAT_FLAG_GENERAL |
@@ -1622,13 +1685,13 @@ _cogl_matrix_has_rotation (const CoglMatrix *matrix)
     return FALSE;
 }
 
-static gboolean
+static CoglBool
 _cogl_matrix_is_general_scale (const CoglMatrix *matrix)
 {
   return (matrix->flags & MAT_FLAG_GENERAL_SCALE) ? TRUE : FALSE;
 }
 
-static gboolean
+static CoglBool
 _cogl_matrix_is_dirty (const CoglMatrix *matrix)
 {
   return (matrix->flags & MAT_DIRTY_ALL) ? TRUE : FALSE;
@@ -1659,9 +1722,18 @@ cogl_matrix_init_from_array (CoglMatrix *matrix, const float *array)
   _COGL_MATRIX_DEBUG_PRINT (matrix);
 }
 
+void
+_cogl_matrix_init_from_matrix_without_inverse (CoglMatrix *matrix,
+                                               const CoglMatrix *src)
+{
+  memcpy (matrix, src, 16 * sizeof (float));
+  matrix->type = src->type;
+  matrix->flags = src->flags | MAT_DIRTY_INVERSE;
+}
+
 static void
 _cogl_matrix_init_from_quaternion (CoglMatrix *matrix,
-                                   CoglQuaternion *quaternion)
+                                   const CoglQuaternion *quaternion)
 {
   float qnorm = _COGL_QUATERNION_NORM (quaternion);
   float s = (qnorm > 0.0f) ? (2.0f / qnorm) : 0.0f;
@@ -1696,11 +1768,89 @@ _cogl_matrix_init_from_quaternion (CoglMatrix *matrix,
 
 void
 cogl_matrix_init_from_quaternion (CoglMatrix *matrix,
-                                  CoglQuaternion *quaternion)
+                                  const CoglQuaternion *quaternion)
 {
   _cogl_matrix_init_from_quaternion (matrix, quaternion);
 }
 
+void
+cogl_matrix_init_from_euler (CoglMatrix *matrix,
+                             const CoglEuler *euler)
+{
+  /* Convert angles to radians */
+  float heading_rad = euler->heading / 180.0f * G_PI;
+  float pitch_rad = euler->pitch / 180.0f * G_PI;
+  float roll_rad = euler->roll / 180.0f * G_PI;
+  /* Pre-calculate the sin and cos */
+  float sin_heading = sinf (heading_rad);
+  float cos_heading = cosf (heading_rad);
+  float sin_pitch = sinf (pitch_rad);
+  float cos_pitch = cosf (pitch_rad);
+  float sin_roll = sinf (roll_rad);
+  float cos_roll = cosf (roll_rad);
+
+  /* These calculations are based on the following website but they
+   * use a different order for the rotations so it has been modified
+   * slightly.
+   * http://www.euclideanspace.com/maths/geometry/
+   *        rotations/conversions/eulerToMatrix/index.htm
+   */
+
+  /* Heading rotation x=0, y=1, z=0 gives:
+   *
+   * [ ch   0   sh   0 ]
+   * [ 0    1   0    0 ]
+   * [ -sh  0   ch   0 ]
+   * [ 0    0   0    1 ]
+   *
+   * Pitch rotation x=1, y=0, z=0 gives:
+   * [ 1    0   0    0 ]
+   * [ 0    cp  -sp  0 ]
+   * [ 0    sp  cp   0 ]
+   * [ 0    0   0    1 ]
+   *
+   * Roll rotation x=0, y=0, z=1 gives:
+   * [ cr   -sr 0    0 ]
+   * [ sr   cr  0    0 ]
+   * [ 0    0   1    0 ]
+   * [ 0    0   0    1 ]
+   *
+   * Heading matrix * pitch matrix =
+   * [ ch   sh*sp    cp*sh   0  ]
+   * [ 0    cp       -sp     0  ]
+   * [ -sh  ch*sp    ch*cp   0  ]
+   * [ 0    0        0       1  ]
+   *
+   * That matrix * roll matrix =
+   * [ ch*cr + sh*sp*sr   sh*sp*cr - ch*sr       sh*cp       0 ]
+   * [     cp*sr                cp*cr             -sp        0 ]
+   * [ ch*sp*sr - sh*cr   sh*sr + ch*sp*cr       ch*cp       0 ]
+   * [       0                    0                0         1 ]
+   */
+
+  matrix->xx = cos_heading * cos_roll + sin_heading * sin_pitch * sin_roll;
+  matrix->yx = cos_pitch * sin_roll;
+  matrix->zx = cos_heading * sin_pitch * sin_roll - sin_heading * cos_roll;
+  matrix->wx = 0.0f;
+
+  matrix->xy = sin_heading * sin_pitch * cos_roll - cos_heading * sin_roll;
+  matrix->yy = cos_pitch * cos_roll;
+  matrix->zy = sin_heading * sin_roll + cos_heading * sin_pitch * cos_roll;
+  matrix->wy = 0.0f;
+
+  matrix->xz = sin_heading * cos_pitch;
+  matrix->yz = -sin_pitch;
+  matrix->zz = cos_heading * cos_pitch;
+  matrix->wz = 0;
+
+  matrix->xw = 0;
+  matrix->yw = 0;
+  matrix->zw = 0;
+  matrix->ww = 1;
+
+  matrix->flags = (MAT_FLAG_GENERAL | MAT_DIRTY_ALL);
+}
+
 /*
  * Transpose a float matrix.
  */
@@ -1782,8 +1932,8 @@ cogl_matrix_view_2d_in_perspective (CoglMatrix *matrix,
                                   height_2d);
 }
 
-gboolean
-cogl_matrix_equal (gconstpointer v1, gconstpointer v2)
+CoglBool
+cogl_matrix_equal (const void *v1, const void *v2)
 {
   const CoglMatrix *a = v1;
   const CoglMatrix *b = v2;
@@ -1896,8 +2046,8 @@ _cogl_matrix_transform_points_f2 (const CoglMatrix *matrix,
 
   for (i = 0; i < n_points; i++)
     {
-      Point2f p = *(Point2f *)((guint8 *)points_in + i * stride_in);
-      Point3f *o = (Point3f *)((guint8 *)points_out + i * stride_out);
+      Point2f p = *(Point2f *)((uint8_t *)points_in + i * stride_in);
+      Point3f *o = (Point3f *)((uint8_t *)points_out + i * stride_out);
 
       o->x = matrix->xx * p.x + matrix->xy * p.y + matrix->xw;
       o->y = matrix->yx * p.x + matrix->yy * p.y + matrix->yw;
@@ -1917,8 +2067,8 @@ _cogl_matrix_project_points_f2 (const CoglMatrix *matrix,
 
   for (i = 0; i < n_points; i++)
     {
-      Point2f p = *(Point2f *)((guint8 *)points_in + i * stride_in);
-      Point4f *o = (Point4f *)((guint8 *)points_out + i * stride_out);
+      Point2f p = *(Point2f *)((uint8_t *)points_in + i * stride_in);
+      Point4f *o = (Point4f *)((uint8_t *)points_out + i * stride_out);
 
       o->x = matrix->xx * p.x + matrix->xy * p.y + matrix->xw;
       o->y = matrix->yx * p.x + matrix->yy * p.y + matrix->yw;
@@ -1939,8 +2089,8 @@ _cogl_matrix_transform_points_f3 (const CoglMatrix *matrix,
 
   for (i = 0; i < n_points; i++)
     {
-      Point3f p = *(Point3f *)((guint8 *)points_in + i * stride_in);
-      Point3f *o = (Point3f *)((guint8 *)points_out + i * stride_out);
+      Point3f p = *(Point3f *)((uint8_t *)points_in + i * stride_in);
+      Point3f *o = (Point3f *)((uint8_t *)points_out + i * stride_out);
 
       o->x = matrix->xx * p.x + matrix->xy * p.y +
              matrix->xz * p.z + matrix->xw;
@@ -1963,8 +2113,8 @@ _cogl_matrix_project_points_f3 (const CoglMatrix *matrix,
 
   for (i = 0; i < n_points; i++)
     {
-      Point3f p = *(Point3f *)((guint8 *)points_in + i * stride_in);
-      Point4f *o = (Point4f *)((guint8 *)points_out + i * stride_out);
+      Point3f p = *(Point3f *)((uint8_t *)points_in + i * stride_in);
+      Point4f *o = (Point4f *)((uint8_t *)points_out + i * stride_out);
 
       o->x = matrix->xx * p.x + matrix->xy * p.y +
              matrix->xz * p.z + matrix->xw;
@@ -1989,8 +2139,8 @@ _cogl_matrix_project_points_f4 (const CoglMatrix *matrix,
 
   for (i = 0; i < n_points; i++)
     {
-      Point4f p = *(Point4f *)((guint8 *)points_in + i * stride_in);
-      Point4f *o = (Point4f *)((guint8 *)points_out + i * stride_out);
+      Point4f p = *(Point4f *)((uint8_t *)points_in + i * stride_in);
+      Point4f *o = (Point4f *)((uint8_t *)points_out + i * stride_out);
 
       o->x = matrix->xx * p.x + matrix->xy * p.y +
              matrix->xz * p.z + matrix->xw * p.w;
@@ -2061,7 +2211,7 @@ cogl_matrix_project_points (const CoglMatrix *matrix,
     }
 }
 
-gboolean
+CoglBool
 cogl_matrix_is_identity (const CoglMatrix *matrix)
 {
   if (!(matrix->flags & MAT_DIRTY_TYPE) &&
