@@ -39,7 +39,7 @@
 
 #include "cogl-internal.h"
 #include "cogl-context-private.h"
-#include "cogl-handle.h"
+#include "cogl-object-private.h"
 
 #include "cogl-texture-private.h"
 #include "cogl-blend-string.h"
@@ -155,7 +155,7 @@ dirty_shader_state (CoglPipeline *pipeline)
                              NULL);
 }
 
-static gboolean
+static CoglBool
 _cogl_pipeline_fragend_arbfp_start (CoglPipeline *pipeline,
                                     int n_layers,
                                     unsigned long pipelines_difference,
@@ -441,7 +441,7 @@ setup_arg (CoglPipeline *pipeline,
 
         if (other_layer == NULL)
           {
-            static gboolean warning_seen = FALSE;
+            static CoglBool warning_seen = FALSE;
             if (!warning_seen)
               {
                 g_warning ("The application is trying to use a texture "
@@ -510,7 +510,7 @@ setup_arg (CoglPipeline *pipeline,
     }
 }
 
-static gboolean
+static CoglBool
 fragend_arbfp_args_equal (CoglPipelineFragendARBfpArg *arg0,
                           CoglPipelineFragendARBfpArg *arg1)
 {
@@ -708,7 +708,7 @@ append_masked_combine (CoglPipeline *arbfp_authority,
                    n_args);
 }
 
-static gboolean
+static CoglBool
 _cogl_pipeline_fragend_arbfp_add_layer (CoglPipeline *pipeline,
                                         CoglPipelineLayer *layer,
                                         unsigned long layers_difference)
@@ -792,7 +792,7 @@ _cogl_pipeline_fragend_arbfp_add_layer (CoglPipeline *pipeline,
   return TRUE;
 }
 
-static gboolean
+static CoglBool
 _cogl_pipeline_fragend_arbfp_passthrough (CoglPipeline *pipeline)
 {
   CoglPipelineShaderState *shader_state = get_shader_state (pipeline);
@@ -808,11 +808,11 @@ _cogl_pipeline_fragend_arbfp_passthrough (CoglPipeline *pipeline)
 typedef struct _UpdateConstantsState
 {
   int unit;
-  gboolean update_all;
+  CoglBool update_all;
   CoglPipelineShaderState *shader_state;
 } UpdateConstantsState;
 
-static gboolean
+static CoglBool
 update_constants_cb (CoglPipeline *pipeline,
                      int layer_index,
                      void *user_data)
@@ -838,7 +838,7 @@ update_constants_cb (CoglPipeline *pipeline,
   return TRUE;
 }
 
-static gboolean
+static CoglBool
 _cogl_pipeline_fragend_arbfp_end (CoglPipeline *pipeline,
                                   unsigned long pipelines_difference)
 {
@@ -917,7 +917,7 @@ _cogl_pipeline_fragend_arbfp_end (CoglPipeline *pipeline,
   else
     {
       CoglProgram *program = shader_state->user_program;
-      gboolean program_changed;
+      CoglBool program_changed;
 
       /* If the shader has changed since it was last flushed then we
          need to update all uniforms */
