@@ -35,35 +35,13 @@
 #include "cogl-pipeline-layer-state.h"
 #include "cogl-internal.h"
 #include "cogl-pipeline-snippet-private.h"
+#include "cogl-sampler-cache-private.h"
 
 #include <glib.h>
 
-/* This isn't defined in the GLES headers */
-#ifndef GL_CLAMP_TO_BORDER
-#define GL_CLAMP_TO_BORDER 0x812d
-#endif
-#ifndef GL_MIRRORED_REPEAT
-#define GL_MIRRORED_REPEAT 0x8370
-#endif
-
 typedef struct _CoglPipelineLayer     CoglPipelineLayer;
 #define COGL_PIPELINE_LAYER(OBJECT) ((CoglPipelineLayer *)OBJECT)
 
-/* GL_ALWAYS is just used here as a value that is known not to clash
- * with any valid GL wrap modes.
- *
- * XXX: keep the values in sync with the CoglPipelineWrapMode enum
- * so no conversion is actually needed.
- */
-typedef enum _CoglPipelineWrapModeInternal
-{
-  COGL_PIPELINE_WRAP_MODE_INTERNAL_REPEAT = GL_REPEAT,
-  COGL_PIPELINE_WRAP_MODE_INTERNAL_MIRRORED_REPEAT = GL_MIRRORED_REPEAT,
-  COGL_PIPELINE_WRAP_MODE_INTERNAL_CLAMP_TO_EDGE = GL_CLAMP_TO_EDGE,
-  COGL_PIPELINE_WRAP_MODE_INTERNAL_CLAMP_TO_BORDER = GL_CLAMP_TO_BORDER,
-  COGL_PIPELINE_WRAP_MODE_INTERNAL_AUTOMATIC = GL_ALWAYS
-} CoglPipelineWrapModeInternal;
-
 /* XXX: should I rename these as
  * COGL_PIPELINE_LAYER_STATE_INDEX_XYZ... ?
  */
@@ -73,8 +51,7 @@ typedef enum
   COGL_PIPELINE_LAYER_STATE_UNIT_INDEX,
   COGL_PIPELINE_LAYER_STATE_TEXTURE_TYPE_INDEX,
   COGL_PIPELINE_LAYER_STATE_TEXTURE_DATA_INDEX,
-  COGL_PIPELINE_LAYER_STATE_FILTERS_INDEX,
-  COGL_PIPELINE_LAYER_STATE_WRAP_MODES_INDEX,
+  COGL_PIPELINE_LAYER_STATE_SAMPLER_INDEX,
   COGL_PIPELINE_LAYER_STATE_COMBINE_INDEX,
   COGL_PIPELINE_LAYER_STATE_COMBINE_CONSTANT_INDEX,
   COGL_PIPELINE_LAYER_STATE_USER_MATRIX_INDEX,
@@ -103,10 +80,8 @@ typedef enum
     1L<<COGL_PIPELINE_LAYER_STATE_TEXTURE_TYPE_INDEX,
   COGL_PIPELINE_LAYER_STATE_TEXTURE_DATA =
     1L<<COGL_PIPELINE_LAYER_STATE_TEXTURE_DATA_INDEX,
-  COGL_PIPELINE_LAYER_STATE_FILTERS =
-    1L<<COGL_PIPELINE_LAYER_STATE_FILTERS_INDEX,
-  COGL_PIPELINE_LAYER_STATE_WRAP_MODES =
-    1L<<COGL_PIPELINE_LAYER_STATE_WRAP_MODES_INDEX,
+  COGL_PIPELINE_LAYER_STATE_SAMPLER =
+    1L<<COGL_PIPELINE_LAYER_STATE_SAMPLER_INDEX,
 
   COGL_PIPELINE_LAYER_STATE_COMBINE =
     1L<<COGL_PIPELINE_LAYER_STATE_COMBINE_INDEX,
@@ -146,9 +121,7 @@ typedef enum
    COGL_PIPELINE_LAYER_STATE_FRAGMENT_SNIPPETS)
 
 #define COGL_PIPELINE_LAYER_STATE_MULTI_PROPERTY \
-  (COGL_PIPELINE_LAYER_STATE_FILTERS | \
-   COGL_PIPELINE_LAYER_STATE_WRAP_MODES | \
-   COGL_PIPELINE_LAYER_STATE_COMBINE | \
+  (COGL_PIPELINE_LAYER_STATE_COMBINE | \
    COGL_PIPELINE_LAYER_STATE_VERTEX_SNIPPETS | \
    COGL_PIPELINE_LAYER_STATE_FRAGMENT_SNIPPETS)
 
@@ -206,7 +179,7 @@ typedef struct
   /* The texture matrix dscribes how to transform texture coordinates */
   CoglMatrix matrix;
 
-  gboolean point_sprite_coords;
+  CoglBool point_sprite_coords;
 
   CoglPipelineSnippetList vertex_snippets;
   CoglPipelineSnippetList fragment_snippets;
@@ -267,12 +240,7 @@ struct _CoglPipelineLayer
      backends. */
   CoglTextureType            texture_type;
 
-  CoglPipelineFilter         mag_filter;
-  CoglPipelineFilter         min_filter;
-
-  CoglPipelineWrapModeInternal wrap_mode_s;
-  CoglPipelineWrapModeInternal wrap_mode_t;
-  CoglPipelineWrapModeInternal wrap_mode_p;
+  const CoglSamplerCacheEntry *sampler_cache_entry;
 
   /* Infrequent differences aren't currently tracked in
    * a separate, dynamically allocated structure as they are
@@ -286,7 +254,7 @@ struct _CoglPipelineLayer
 
 };
 
-typedef gboolean
+typedef CoglBool
 (*CoglPipelineLayerStateComparitor) (CoglPipelineLayer *authority0,
                                      CoglPipelineLayer *authority1);
 
@@ -310,7 +278,7 @@ _cogl_pipeline_layer_resolve_authorities (CoglPipelineLayer *layer,
                                           unsigned long differences,
                                           CoglPipelineLayer **authorities);
 
-gboolean
+CoglBool
 _cogl_pipeline_layer_equal (CoglPipelineLayer *layer0,
                             CoglPipelineLayer *layer1,
                             unsigned long differences_mask,
@@ -324,10 +292,10 @@ _cogl_pipeline_layer_pre_change_notify (CoglPipeline *required_owner,
 void
 _cogl_pipeline_layer_prune_redundant_ancestry (CoglPipelineLayer *layer);
 
-gboolean
+CoglBool
 _cogl_pipeline_layer_has_alpha (CoglPipelineLayer *layer);
 
-gboolean
+CoglBool
 _cogl_pipeline_layer_has_user_matrix (CoglPipeline *pipeline,
                                       int layer_index);
 
@@ -341,15 +309,18 @@ _cogl_pipeline_layer_pre_paint (CoglPipelineLayer *layerr);
 
 void
 _cogl_pipeline_layer_get_wrap_modes (CoglPipelineLayer *layer,
-                                     CoglPipelineWrapModeInternal *wrap_mode_s,
-                                     CoglPipelineWrapModeInternal *wrap_mode_t,
-                                     CoglPipelineWrapModeInternal *wrap_mode_r);
+                                     CoglSamplerCacheWrapMode *wrap_mode_s,
+                                     CoglSamplerCacheWrapMode *wrap_mode_t,
+                                     CoglSamplerCacheWrapMode *wrap_mode_r);
 
 void
 _cogl_pipeline_layer_get_filters (CoglPipelineLayer *layer,
                                   CoglPipelineFilter *min_filter,
                                   CoglPipelineFilter *mag_filter);
 
+const CoglSamplerCacheEntry *
+_cogl_pipeline_layer_get_sampler_state (CoglPipelineLayer *layer);
+
 void
 _cogl_pipeline_get_layer_filters (CoglPipeline *pipeline,
                                   int layer_index,
@@ -401,7 +372,7 @@ _cogl_pipeline_layer_get_texture (CoglPipelineLayer *layer);
 int
 _cogl_pipeline_layer_get_unit_index (CoglPipelineLayer *layer);
 
-gboolean
+CoglBool
 _cogl_pipeline_layer_needs_combine_separate
                                        (CoglPipelineLayer *combine_authority);
 
