@@ -21,14 +21,20 @@
  *
  */
 
-#if !defined(__COGL_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
+#if !defined(__COGL_H_INSIDE__) && !defined(COGL_COMPILATION)
 #error "Only <cogl/cogl.h> can be included directly."
 #endif
 
 #ifndef __COGL_PIPELINE_H__
 #define __COGL_PIPELINE_H__
 
+/* We forward declare the CoglPipeline type here to avoid some circular
+ * dependency issues with the following headers.
+ */
+typedef struct _CoglPipeline CoglPipeline;
+
 #include <cogl/cogl-types.h>
+#include <cogl/cogl-context.h>
 #include <cogl/cogl-snippet.h>
 
 G_BEGIN_DECLS
@@ -48,12 +54,12 @@ G_BEGIN_DECLS
  * performs fragment processing including depth testing and texture
  * mapping. Finally it blends the result with the framebuffer.
  */
-typedef struct _CoglPipeline	      CoglPipeline;
 
 #define COGL_PIPELINE(OBJECT) ((CoglPipeline *)OBJECT)
 
 /**
  * cogl_pipeline_new:
+ * @context: a #CoglContext
  *
  * Allocates and initializes a default simple pipeline that will color
  * a primitive white.
@@ -64,7 +70,7 @@ typedef struct _CoglPipeline	      CoglPipeline;
  * Stability: Unstable
  */
 CoglPipeline *
-cogl_pipeline_new (void);
+cogl_pipeline_new (CoglContext *context);
 
 /**
  * cogl_pipeline_copy:
@@ -89,18 +95,18 @@ cogl_pipeline_copy (CoglPipeline *source);
 
 /**
  * cogl_is_pipeline:
- * @handle: A CoglHandle
+ * @object: A #CoglObject
  *
- * Gets whether the given handle references an existing pipeline object.
+ * Gets whether the given @object references an existing pipeline object.
  *
- * Return value: %TRUE if the handle references a #CoglPipeline,
+ * Return value: %TRUE if the @object references a #CoglPipeline,
  *   %FALSE otherwise
  *
  * Since: 2.0
  * Stability: Unstable
  */
-gboolean
-cogl_is_pipeline (CoglHandle handle);
+CoglBool
+cogl_is_pipeline (void *object);
 
 /**
  * CoglPipelineLayerCallback:
@@ -114,7 +120,7 @@ cogl_is_pipeline (CoglHandle handle);
  * Since: 2.0
  * Stability: Unstable
  */
-typedef gboolean (*CoglPipelineLayerCallback) (CoglPipeline *pipeline,
+typedef CoglBool (*CoglPipelineLayerCallback) (CoglPipeline *pipeline,
                                                int layer_index,
                                                void *user_data);
 
