@@ -24,7 +24,7 @@
  *   Robert Bragg <robert@linux.intel.com>
  */
 
-#if !defined(__COGL_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
+#if !defined(__COGL_H_INSIDE__) && !defined(COGL_COMPILATION)
 #error "Only <cogl/cogl.h> can be included directly."
 #endif
 
@@ -59,7 +59,7 @@ G_BEGIN_DECLS
  * component. The scalar component is normally referred to as w and the
  * vector might either be referred to as v or a (for axis) or expanded
  * with the individual components: (x, y, z) A full quaternion would
- * then be written as <pre>[w (x, y, z)]</pre>.
+ * then be written as <literal>[w (x, y, z)]</literal>.
  *
  * Quaternions can be considered to represent an axis and angle
  * pair although sadly these numbers are buried somewhat under some
@@ -127,6 +127,7 @@ struct _CoglQuaternion
   float y;
   float z;
 
+  /*< private >*/
   float padding0;
   float padding1;
   float padding2;
@@ -199,7 +200,7 @@ cogl_quaternion_init_identity (CoglQuaternion *quaternion);
 /**
  * cogl_quaternion_init_from_array:
  * @quaternion: A #CoglQuaternion
- * @array: An array of 4 floats (x,y,z),w
+ * @array: An array of 4 floats w,(x,y,z)
  *
  * Initializes a [w (x, y,z)] quaternion directly from an array of 4
  * floats: [w,x,y,z].
@@ -238,7 +239,7 @@ cogl_quaternion_init_from_y_rotation (CoglQuaternion *quaternion,
 /**
  * cogl_quaternion_init_from_z_rotation:
  * @quaternion: An uninitialized #CoglQuaternion
- * @angle: The angle to rotate around the y axis
+ * @angle: The angle to rotate around the z axis
  *
  *
  * Since: 2.0
@@ -247,10 +248,24 @@ void
 cogl_quaternion_init_from_z_rotation (CoglQuaternion *quaternion,
                                       float angle);
 
+/**
+ * cogl_quaternion_init_from_euler:
+ * @quaternion: A #CoglQuaternion
+ * @euler: A #CoglEuler with which to initialize the quaternion
+ *
+ * Since: 2.0
+ */
 void
 cogl_quaternion_init_from_euler (CoglQuaternion *quaternion,
                                  const CoglEuler *euler);
 
+/**
+ * cogl_quaternion_init_from_quaternion:
+ * @quaternion: A #CoglQuaternion
+ * @src: A #CoglQuaternion with which to initialize @quaternion
+ *
+ * Since: 2.0
+ */
 void
 cogl_quaternion_init_from_quaternion (CoglQuaternion *quaternion,
                                       CoglQuaternion *src);
@@ -285,8 +300,8 @@ cogl_quaternion_init_from_matrix (CoglQuaternion *quaternion,
  *
  * Since: 2.0
  */
-gboolean
-cogl_quaternion_equal (gconstpointer v1, gconstpointer v2);
+CoglBool
+cogl_quaternion_equal (const void *v1, const void *v2);
 
 /**
  * cogl_quaternion_copy:
@@ -379,6 +394,9 @@ cogl_quaternion_invert (CoglQuaternion *quaternion);
  * so the rotations are applied @right to @left. This is similar to the
  * combining of matrices.
  *
+ * <note>It is possible to multiply the @a quaternion in-place, so
+ * @result can be equal to @a but can't be equal to @b.</note>
+ *
  * Since: 2.0
  */
 void
