@@ -69,8 +69,7 @@ _cogl_texture_2d_set_wrap_mode_parameters (CoglTexture *tex,
                                            GLenum wrap_mode_p)
 {
   CoglTexture2D *tex_2d = COGL_TEXTURE_2D (tex);
-
-  _COGL_GET_CONTEXT (ctx, NO_RETVAL);
+  CoglContext *ctx = tex->context;
 
   /* Only set the wrap mode if it's different from the current value
      to avoid too many GL calls. Texture 2D doesn't make use of the r
@@ -104,7 +103,8 @@ _cogl_texture_2d_free (CoglTexture2D *tex_2d)
 }
 
 static CoglBool
-_cogl_texture_2d_can_create (unsigned int width,
+_cogl_texture_2d_can_create (CoglContext *ctx,
+                             unsigned int width,
                              unsigned int height,
                              CoglPixelFormat internal_format)
 {
@@ -112,8 +112,6 @@ _cogl_texture_2d_can_create (unsigned int width,
   GLenum gl_format;
   GLenum gl_type;
 
-  _COGL_GET_CONTEXT (ctx, FALSE);
-
   /* If NPOT textures aren't supported then the size must be a power
      of two */
   if (!cogl_has_feature (ctx, COGL_FEATURE_ID_TEXTURE_NPOT_BASIC) &&
@@ -150,14 +148,15 @@ _cogl_texture_2d_set_auto_mipmap (CoglTexture *tex,
 }
 
 static CoglTexture2D *
-_cogl_texture_2d_create_base (unsigned int     width,
-                              unsigned int     height,
-                              CoglPixelFormat  internal_format)
+_cogl_texture_2d_create_base (CoglContext *ctx,
+                              int width,
+                              int height,
+                              CoglPixelFormat internal_format)
 {
   CoglTexture2D *tex_2d = g_new (CoglTexture2D, 1);
   CoglTexture *tex = COGL_TEXTURE (tex_2d);
 
-  _cogl_texture_init (tex, &cogl_texture_2d_vtable);
+  _cogl_texture_init (tex, ctx, &cogl_texture_2d_vtable);
 
   tex_2d->width = width;
   tex_2d->height = height;
@@ -195,7 +194,7 @@ cogl_texture_2d_new_with_size (CoglContext *ctx,
   if (internal_format == COGL_PIXEL_FORMAT_ANY)
     internal_format = COGL_PIXEL_FORMAT_RGBA_8888_PRE;
 
-  if (!_cogl_texture_2d_can_create (width, height, internal_format))
+  if (!_cogl_texture_2d_can_create (ctx, width, height, internal_format))
     {
       g_set_error (error, COGL_TEXTURE_ERROR,
                    COGL_TEXTURE_ERROR_SIZE,
@@ -210,7 +209,8 @@ cogl_texture_2d_new_with_size (CoglContext *ctx,
                                                             &gl_format,
                                                             &gl_type);
 
-  tex_2d = _cogl_texture_2d_create_base (width, height,
+  tex_2d = _cogl_texture_2d_create_base (ctx,
+                                         width, height,
                                          internal_format);
 
   ctx->texture_driver->gen (ctx, GL_TEXTURE_2D, 1, &tex_2d->gl_texture);
@@ -244,7 +244,8 @@ cogl_texture_2d_new_from_bitmap (CoglBitmap *bmp,
     _cogl_texture_determine_internal_format (cogl_bitmap_get_format (bmp),
                                              internal_format);
 
-  if (!_cogl_texture_2d_can_create (cogl_bitmap_get_width (bmp),
+  if (!_cogl_texture_2d_can_create (ctx,
+                                    cogl_bitmap_get_width (bmp),
                                     cogl_bitmap_get_height (bmp),
                                     internal_format))
     {
@@ -269,7 +270,8 @@ cogl_texture_2d_new_from_bitmap (CoglBitmap *bmp,
       return NULL;
     }
 
-  tex_2d = _cogl_texture_2d_create_base (cogl_bitmap_get_width (bmp),
+  tex_2d = _cogl_texture_2d_create_base (ctx,
+                                         cogl_bitmap_get_width (bmp),
                                          cogl_bitmap_get_height (bmp),
                                          internal_format);
 
@@ -343,7 +345,7 @@ cogl_texture_2d_new_from_data (CoglContext *ctx,
 
 CoglTexture2D *
 cogl_texture_2d_new_from_foreign (CoglContext *ctx,
-                                  GLuint gl_handle,
+                                  unsigned int gl_handle,
                                   int width,
                                   int height,
                                   CoglPixelFormat format,
@@ -353,17 +355,24 @@ cogl_texture_2d_new_from_foreign (CoglContext *ctx,
    * in GLES, hence such a function prototype.
    */
 
-  GLenum         gl_error      = 0;
-  GLint          gl_compressed = GL_FALSE;
-  GLenum         gl_int_format = 0;
+  GLenum gl_error = 0;
+  GLint gl_compressed = GL_FALSE;
+  GLenum gl_int_format = 0;
   CoglTexture2D *tex_2d;
 
+  /* Assert it is a valid GL texture object */
+  g_return_val_if_fail (ctx->glIsTexture (gl_handle), NULL);
+
   if (!ctx->texture_driver->allows_foreign_gl_target (ctx, GL_TEXTURE_2D))
-    return NULL;
+    {
+      g_set_error (error,
+                   COGL_ERROR,
+                   COGL_ERROR_UNSUPPORTED,
+                   "Foreign GL_TEXTURE_2D textures are not "
+                   "supported by your system");
+      return NULL;
+    }
 
-  /* Make sure it is a valid GL texture object */
-  if (!ctx->glIsTexture (gl_handle))
-    return NULL;
 
   /* Make sure binding succeeds */
   while ((gl_error = ctx->glGetError ()) != GL_NO_ERROR)
@@ -371,7 +380,13 @@ cogl_texture_2d_new_from_foreign (CoglContext *ctx,
 
   _cogl_bind_gl_texture_transient (GL_TEXTURE_2D, gl_handle, TRUE);
   if (ctx->glGetError () != GL_NO_ERROR)
-    return NULL;
+    {
+      g_set_error (error,
+                   COGL_ERROR,
+                   COGL_ERROR_UNSUPPORTED,
+                   "Failed to bind foreign GL_TEXTURE_2D texture");
+      return NULL;
+    }
 
   /* Obtain texture parameters
      (only level 0 we are interested in) */
@@ -398,7 +413,13 @@ cogl_texture_2d_new_from_foreign (CoglContext *ctx,
       if (!ctx->driver_vtable->pixel_format_from_gl_internal (ctx,
                                                               gl_int_format,
                                                               &format))
-        return NULL;
+        {
+          g_set_error (error,
+                       COGL_ERROR,
+                       COGL_ERROR_UNSUPPORTED,
+                       "Unsupported internal format for foreign texture");
+          return NULL;
+        }
     }
   else
 #endif
@@ -420,18 +441,23 @@ cogl_texture_2d_new_from_foreign (CoglContext *ctx,
    */
 
   /* Validate width and height */
-  if (width <= 0 || height <= 0)
-    return NULL;
+  g_return_val_if_fail (width > 0 && height > 0, NULL);
 
   /* Compressed texture images not supported */
   if (gl_compressed == GL_TRUE)
-    return NULL;
+    {
+      g_set_error (error,
+                   COGL_ERROR,
+                   COGL_ERROR_UNSUPPORTED,
+                   "Compressed foreign textures aren't currently supported");
+      return NULL;
+    }
 
   /* Note: previously this code would query the texture object for
      whether it has GL_GENERATE_MIPMAP enabled to determine whether to
      auto-generate the mipmap. This doesn't make much sense any more
      since Cogl switch to using glGenerateMipmap. Ideally I think
-     cogl_texture_new_from_foreign should take a flags parameter so
+     cogl_texture_2d_new_from_foreign should take a flags parameter so
      that the application can decide whether it wants
      auto-mipmapping. To be compatible with existing code, Cogl now
      disables its own auto-mipmapping but leaves the value of
@@ -439,7 +465,8 @@ cogl_texture_2d_new_from_foreign (CoglContext *ctx,
      the dirtiness tracking that Cogl would do. */
 
   /* Create new texture */
-  tex_2d = _cogl_texture_2d_create_base (width, height,
+  tex_2d = _cogl_texture_2d_create_base (ctx,
+                                         width, height,
                                          format);
   _cogl_texture_2d_set_auto_mipmap (COGL_TEXTURE (tex_2d), FALSE);
 
@@ -482,7 +509,8 @@ _cogl_egl_texture_2d_new_from_image (CoglContext *ctx,
                         COGL_PRIVATE_FEATURE_TEXTURE_2D_FROM_EGL_IMAGE,
                         NULL);
 
-  tex_2d = _cogl_texture_2d_create_base (width, height,
+  tex_2d = _cogl_texture_2d_create_base (ctx,
+                                         width, height,
                                          format);
 
   ctx->texture_driver->gen (ctx, GL_TEXTURE_2D, 1, &tex_2d->gl_texture);
@@ -593,10 +621,12 @@ _cogl_texture_2d_copy_from_framebuffer (CoglTexture2D *tex_2d,
                                         int width,
                                         int height)
 {
-  _COGL_GET_CONTEXT (ctx, NO_RETVAL);
+  CoglContext *ctx;
 
   _COGL_RETURN_IF_FAIL (cogl_is_texture_2d (tex_2d));
 
+  ctx = COGL_TEXTURE (tex_2d)->context;
+
   /* Make sure the current framebuffers are bound, though we don't need to
    * flush the clip state here since we aren't going to draw to the
    * framebuffer. */
@@ -634,8 +664,7 @@ static CoglBool
 _cogl_texture_2d_can_hardware_repeat (CoglTexture *tex)
 {
   CoglTexture2D *tex_2d = COGL_TEXTURE_2D (tex);
-
-  _COGL_GET_CONTEXT (ctx, FALSE);
+  CoglContext *ctx = tex->context;
 
   if (cogl_has_feature (ctx, COGL_FEATURE_ID_TEXTURE_NPOT_REPEAT) ||
       (_cogl_util_is_pot (tex_2d->width) &&
@@ -698,8 +727,7 @@ _cogl_texture_2d_set_filters (CoglTexture *tex,
                               GLenum       mag_filter)
 {
   CoglTexture2D *tex_2d = COGL_TEXTURE_2D (tex);
-
-  _COGL_GET_CONTEXT (ctx, NO_RETVAL);
+  CoglContext *ctx = tex->context;
 
   if (min_filter == tex_2d->min_filter
       && mag_filter == tex_2d->mag_filter)
@@ -721,8 +749,7 @@ static void
 _cogl_texture_2d_pre_paint (CoglTexture *tex, CoglTexturePrePaintFlags flags)
 {
   CoglTexture2D *tex_2d = COGL_TEXTURE_2D (tex);
-
-  _COGL_GET_CONTEXT (ctx, NO_RETVAL);
+  CoglContext *ctx = tex->context;
 
   /* Only update if the mipmaps are dirty */
   if ((flags & COGL_TEXTURE_NEEDS_MIPMAP) &&
@@ -774,12 +801,11 @@ _cogl_texture_2d_set_region (CoglTexture    *tex,
                              CoglBitmap     *bmp)
 {
   CoglTexture2D *tex_2d = COGL_TEXTURE_2D (tex);
+  CoglContext *ctx = tex->context;
   GLenum gl_format;
   GLenum gl_type;
   uint8_t *data;
 
-  _COGL_GET_CONTEXT (ctx, FALSE);
-
   bmp = _cogl_texture_prepare_for_upload (bmp,
                                           cogl_texture_get_format (tex),
                                           NULL,
@@ -828,12 +854,11 @@ _cogl_texture_2d_get_data (CoglTexture *tex,
                            unsigned int rowstride,
                            uint8_t *data)
 {
-  CoglTexture2D   *tex_2d = COGL_TEXTURE_2D (tex);
-  int              bpp;
-  GLenum           gl_format;
-  GLenum           gl_type;
-
-  _COGL_GET_CONTEXT (ctx, FALSE);
+  CoglTexture2D *tex_2d = COGL_TEXTURE_2D (tex);
+  CoglContext *ctx = tex->context;
+  int bpp;
+  GLenum gl_format;
+  GLenum gl_type;
 
   bpp = _cogl_pixel_format_get_bytes_per_pixel (format);
 
