@@ -21,24 +21,63 @@
  *
  */
 
-#if !defined(__COGL_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
+#if !defined(__COGL_H_INSIDE__) && !defined(COGL_COMPILATION)
 #error "Only <cogl/cogl.h> can be included directly."
 #endif
 
 #ifndef __COGL_TYPES_H__
 #define __COGL_TYPES_H__
 
+#include <stdint.h>
 #include <glib-object.h>
 
 #include <cogl/cogl-defines.h>
 
 G_BEGIN_DECLS
 
+/**
+ * CoglBool:
+ *
+ * A boolean data type used throughout the Cogl C api. This should be
+ * used in conjunction with the %TRUE and %FALSE macro defines for
+ * setting and testing boolean values.
+ *
+ * Since: 2.0
+ * Stability: stable
+ */
+typedef int CoglBool;
+
+/**
+ * TRUE:
+ *
+ * A constant to be used with #CoglBool types to indicate a boolean in
+ * the "true" state.
+ *
+ * Since: 2.0
+ * Stability: stable
+ */
+#ifndef TRUE
+#define TRUE 1
+#endif
+
+/**
+ * TRUE:
+ *
+ * A constant to be used with #CoglBool types to indicate a boolean in
+ * the "false" state.
+ *
+ * Since: 2.0
+ * Stability: stable
+ */
+#ifndef FALSE
+#define FALSE 0
+#endif
+
 /* Some structures are meant to be opaque but they have public
    definitions because we want the size to be public so they can be
    allocated on the stack. This macro is used to ensure that users
    don't accidentally access private members */
-#ifdef CLUTTER_COMPILATION
+#ifdef COGL_COMPILATION
 #define COGL_PRIVATE(x) x
 #else
 #define COGL_PRIVATE(x) private_member_ ## x
@@ -60,7 +99,7 @@ typedef struct { \
  * Type used for storing references to cogl objects, the CoglHandle is
  * a fully opaque type without any public data members.
  */
-typedef gpointer CoglHandle;
+typedef void * CoglHandle;
 
 /**
  * COGL_INVALID_HANDLE:
@@ -99,7 +138,7 @@ cogl_handle_unref (CoglHandle handle);
  * cogl_object_ref: (skip)
  * @object: a #CoglObject
  *
- * Increases the reference count of @handle by 1
+ * Increases the reference count of @object by 1
  *
  * Returns: the @object, with its reference count increased
  */
@@ -142,7 +181,7 @@ typedef struct _CoglEuler CoglEuler;
  *
  * Fixed point number using a (16.16) notation.
  */
-typedef gint32 CoglFixed;
+typedef int32_t CoglFixed;
 
 #define COGL_TYPE_FIXED         (cogl_fixed_get_type ())
 GType
@@ -156,7 +195,7 @@ cogl_fixed_get_type (void) G_GNUC_CONST;
  *
  * Since: 1.0
  */
-typedef gint32 CoglAngle;
+typedef int32_t CoglAngle;
 
 typedef struct _CoglColor               CoglColor;
 typedef struct _CoglTextureVertex       CoglTextureVertex;
@@ -420,17 +459,17 @@ typedef enum
 struct _CoglColor
 {
   /*< private >*/
-  guint8 COGL_PRIVATE (red);
-  guint8 COGL_PRIVATE (green);
-  guint8 COGL_PRIVATE (blue);
+  uint8_t COGL_PRIVATE (red);
+  uint8_t COGL_PRIVATE (green);
+  uint8_t COGL_PRIVATE (blue);
 
-  guint8 COGL_PRIVATE (alpha);
+  uint8_t COGL_PRIVATE (alpha);
 
   /* padding in case we want to change to floats at
    * some point */
-  guint32 COGL_PRIVATE (padding0);
-  guint32 COGL_PRIVATE (padding1);
-  guint32 COGL_PRIVATE (padding2);
+  uint32_t COGL_PRIVATE (padding0);
+  uint32_t COGL_PRIVATE (padding1);
+  uint32_t COGL_PRIVATE (padding2);
 };
 COGL_STRUCT_SIZE_ASSERT (CoglColor, 16);
 
@@ -698,7 +737,8 @@ typedef enum
 
 typedef enum { /*< prefix=COGL_RENDERER_ERROR >*/
   COGL_RENDERER_ERROR_NOT_FOUND,
-  COGL_RENDERER_ERROR_XLIB_DISPLAY_OPEN
+  COGL_RENDERER_ERROR_XLIB_DISPLAY_OPEN,
+  COGL_RENDERER_ERROR_BAD_CONSTRAINT
 } CoglRendererError;
 
 /*
