@@ -34,6 +34,11 @@
 #include <stdio.h>
 #endif
 
+/* Double check that config.h has been included */
+#if !defined (GETTEXT_PACKAGE) && !defined (_COGL_IN_TEST_BITMASK)
+#error "config.h must be included before including cogl-util.h"
+#endif
+
 /* When compiling with Visual Studio, symbols that represent data that
    are exported out of the DLL need to be marked with the dllexport
    attribute. */
@@ -47,27 +52,6 @@
 #define COGL_EXPORT
 #endif
 
-/* Macros to handle compacting a 3-component version number into an
-   int for quick comparison. This assumes all of the components are
-   <= 1023 */
-#define COGL_VERSION_COMPONENT_BITS 10
-#define COGL_VERSION_MAX_COMPONENT_VALUE \
-  ((1 << COGL_VERSION_COMPONENT_BITS) - 1)
-
-#define COGL_VERSION_ENCODE(major, minor, micro)        \
-  (((major) << (COGL_VERSION_COMPONENT_BITS * 2)) |     \
-   ((minor) << COGL_VERSION_COMPONENT_BITS)             \
-   | (micro))
-
-#define COGL_VERSION_GET_MAJOR(version) \
-  (((version) >> 20) & COGL_VERSION_MAX_COMPONENT_VALUE)
-
-#define COGL_VERSION_GET_MINOR(version) \
-  (((version) >> 10) & COGL_VERSION_MAX_COMPONENT_VALUE)
-
-#define COGL_VERSION_GET_MICRO(version) \
-  ((version) & COGL_VERSION_MAX_COMPONENT_VALUE)
-
 int
 _cogl_util_next_p2 (int a);
 
@@ -82,12 +66,12 @@ _cogl_util_next_p2 (int a);
    It xors the integer reinterpretations of -1.0f and 1.0f. In theory
    they should only differ by the signbit so that gives a mask for the
    sign which we can just test against the value */
-static inline gboolean
+static inline CoglBool
 cogl_util_float_signbit (float x)
 {
-  static const union { float f; guint32 i; } negative_one = { -1.0f };
-  static const union { float f; guint32 i; } positive_one = { +1.0f };
-  union { float f; guint32 i; } value = { x };
+  static const union { float f; uint32_t i; } negative_one = { -1.0f };
+  static const union { float f; uint32_t i; } positive_one = { +1.0f };
+  union { float f; uint32_t i; } value = { x };
 
   return !!((negative_one.i ^ positive_one.i) & value.i);
 }
@@ -102,7 +86,7 @@ cogl_util_float_signbit (float x)
 #define COGL_UTIL_NEARBYINT(x) ((int) ((x) < 0.0f ? (x) - 0.5f : (x) + 0.5f))
 
 /* Returns whether the given integer is a power of two */
-static inline gboolean
+static inline CoglBool
 _cogl_util_is_pot (unsigned int num)
 {
   /* Make sure there is only one bit set */
@@ -117,10 +101,10 @@ _cogl_util_is_pot (unsigned int num)
  */
 static inline unsigned int
 _cogl_util_one_at_a_time_hash (unsigned int hash,
-                               void *key,
+                               const void *key,
                                size_t bytes)
 {
-  unsigned char *p = key;
+  const unsigned char *p = key;
   int i;
 
   for (i = 0; i < bytes; i++)
@@ -238,4 +222,60 @@ _cogl_util_pixel_format_from_masks (unsigned long r_mask,
                                     int depth, int bpp,
                                     int byte_order);
 
+/* Since we can't rely on _Static_assert always being available for
+ * all compilers we have limited static assert that can be used in
+ * C code but not in headers.
+ */
+#define _COGL_TYPEDEF_ASSERT(EXPRESSION) \
+  typedef struct { char Compile_Time_Assertion[(EXPRESSION) ? 1 : -1]; } \
+  G_PASTE (_GStaticAssert_, __LINE__)
+
+/* _COGL_STATIC_ASSERT:
+ * @expression: An expression to assert evaluates to true at compile
+ *              time.
+ * @message: A message to print to the console if the assertion fails
+ *           at compile time.
+ *
+ * Allows you to assert that an expression evaluates to true at
+ * compile time and aborts compilation if not. If possible message
+ * will also be printed if the assertion fails.
+ *
+ * Note: Only Gcc >= 4.6 supports the c11 _Static_assert which lets us
+ * print a nice message if the compile time assertion fails.
+ *
+ * Note: this assertion macro can only be used in C code where it is
+ * valid to use a typedef. This macro should not be used in headers
+ * because we can't guarantee a unique name for the typedef due to
+ * the name being based on the line number of the file it's used in.
+ *
+ * Although we can remove this limitation if the compiler supports
+ * _Static_assert we currently choose to maintain the limitation in
+ * any case to help ensure we don't accidentally create code that
+ * doesn't compile on some toolchains because we forgot about this
+ * limitation.
+ */
+#ifdef HAVE_STATIC_ASSERT
+#define _COGL_STATIC_ASSERT(EXPRESSION, MESSAGE) \
+  _Static_assert (EXPRESSION, MESSAGE); \
+  _COGL_TYPEDEF_ASSERT(EXPRESSION)
+#else
+#define _COGL_STATIC_ASSERT(EXPRESSION, MESSAGE) \
+  _COGL_TYPEDEF_ASSERT(EXPRESSION)
+
+/* So that we can safely use _Static_assert() if we want to add
+ * assertions to internal headers we define it to a NOP here
+ * if it's not supported by the compiler. */
+#define _Static_assert(EXPRESSION, MESSAGE)
+#endif
+
+#ifdef HAVE_MEMMEM
+#define _cogl_util_memmem memmem
+#else
+char *
+_cogl_util_memmem (const void *haystack,
+                   size_t haystack_len,
+                   const void *needle,
+                   size_t needle_len);
+#endif
+
 #endif /* __COGL_UTIL_H */
