@@ -21,7 +21,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#if !defined(__COGL_XLIB_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
+#if !defined(__COGL_XLIB_H_INSIDE__) && !defined(COGL_COMPILATION)
 #error "Only <cogl/cogl-xlib.h> can be included directly."
 #endif
 
@@ -144,7 +144,7 @@ cogl_xlib_renderer_set_foreign_display (CoglRenderer *renderer,
  */
 void
 cogl_xlib_renderer_set_event_retrieval_enabled (CoglRenderer *renderer,
-                                                gboolean enable);
+                                                CoglBool enable);
 
 #define cogl_xlib_renderer_get_display cogl_xlib_renderer_get_display_EXP
 Display *
