@@ -437,6 +437,9 @@ update_winsys_features (CoglContext *context, GError **error)
     {
       glx_renderer->pf_glXGetVideoSync = NULL;
       glx_renderer->pf_glXWaitVideoSync = NULL;
+      COGL_FLAGS_SET (context->winsys_features,
+                      COGL_WINSYS_FEATURE_VBLANK_COUNTER,
+                      FALSE);
     }
 
   if (glx_renderer->pf_glXWaitVideoSync)
