@@ -37,7 +37,7 @@ _cogl_winsys_error_quark (void)
 }
 
 /* FIXME: we should distinguish renderer and context features */
-gboolean
+CoglBool
 _cogl_winsys_has_feature (CoglWinsysFeature feature)
 {
   _COGL_GET_CONTEXT (ctx, FALSE);
