@@ -17,8 +17,8 @@ main (int argc, char **argv)
         {0.7, -0.7, 0x00, 0x00, 0xff, 0xff}
     };
     CoglPrimitive *triangle;
-    CoglHandle tex;
-    CoglHandle offscreen;
+    CoglTexture *tex;
+    CoglOffscreen *offscreen;
     CoglFramebuffer *offscreen_fb;
     CoglPipeline *pipeline;
 
@@ -84,7 +84,7 @@ main (int argc, char **argv)
     for (;;) {
         CoglPollFD *poll_fds;
         int n_poll_fds;
-        gint64 timeout;
+        int64_t timeout;
         CoglPipeline *texture_pipeline;
 
         cogl_framebuffer_clear4f (fb, COGL_BUFFER_BIT_COLOR, 0, 0, 0, 1);
